@@ -22,8 +22,8 @@ static char THIS_FILE[] = __FILE__;
 
 // FIXME - should compass mode be made a separate class?
 
-CDasherButtons::CDasherButtons(Dasher::CEventHandler * pEventHandler, CSettingsStore *pSettingsStore, CDasherInterfaceBase *pInterface, int iNumBoxes, int iStyle, bool bMenu)
-  : CInputFilter(pEventHandler, pSettingsStore, pInterface) {
+CDasherButtons::CDasherButtons(Dasher::CEventHandler * pEventHandler, CSettingsStore *pSettingsStore, CDasherInterfaceBase *pInterface, int iNumBoxes, int iStyle, bool bMenu, long long int iID, const char *szName)
+  : CInputFilter(pEventHandler, pSettingsStore, pInterface, iID, 1, szName) {
 
   m_pBoxes = 0;
 
@@ -99,13 +99,13 @@ void CDasherButtons::SetupBoxes()
 
     // Make this the inverse of the right zoom option
 
-    m_pBoxes[0].iTop = -2048 *  m_pBoxes[1].iTop / (2048 -  m_pBoxes[1].iTop);
-    m_pBoxes[0].iBottom = 4096 - m_pBoxes[0].iTop;
+    m_pBoxes[3].iTop = -2048 *  m_pBoxes[1].iTop / (2048 -  m_pBoxes[1].iTop);
+    m_pBoxes[3].iBottom = 4096 - m_pBoxes[3].iTop;
 
-    m_pBoxes[2].iTop = -iTargetWidth;
-    m_pBoxes[2].iBottom = iDasherY - iTargetWidth;
-    m_pBoxes[3].iTop = iTargetWidth;
-    m_pBoxes[3].iBottom = iDasherY + iTargetWidth;
+    m_pBoxes[0].iTop = -iTargetWidth;
+    m_pBoxes[0].iBottom = iDasherY - iTargetWidth;
+    m_pBoxes[2].iTop = iTargetWidth;
+    m_pBoxes[2].iBottom = iDasherY + iTargetWidth;
 
     m_pBoxes[0].iDisplayTop = m_pBoxes[0].iTop; 
     m_pBoxes[0].iDisplayBottom = m_pBoxes[0].iBottom;
@@ -249,7 +249,7 @@ void CDasherButtons::SetupBoxes()
   iActiveBox = 0;
 }
 
-void CDasherButtons::DecorateView(CDasherView *pView) {
+bool CDasherButtons::DecorateView(CDasherView *pView) {
   if(m_iStyle == 2) {
     CDasherScreen *pScreen(pView->Screen());
 
@@ -314,8 +314,10 @@ void CDasherButtons::DecorateView(CDasherView *pView) {
       if(i != iActiveBox)
 	pView->NewDrawGoTo(m_pBoxes[i].iDisplayTop, m_pBoxes[i].iDisplayBottom, false);
     }
-    pView->NewDrawGoTo(m_pBoxes[iActiveBox].iDisplayTop, m_pBoxes[iActiveBox].iDisplayBottom, m_bMenu);
+    pView->NewDrawGoTo(m_pBoxes[iActiveBox].iDisplayTop, m_pBoxes[iActiveBox].iDisplayBottom, m_bMenu || m_bHighlight);
   }
+
+  return true;
 }
  
 
@@ -324,47 +326,62 @@ void CDasherButtons::KeyDown(int iTime, int iId, CDasherModel *pModel) {
   if(m_bMenu) {
     switch(iId) {
     case 1:
+    case 4:
       ++iActiveBox;
       if(iActiveBox == m_iNumBoxes)
 	iActiveBox = 0;
       break;
     case 2:
+    case 3:
       pModel->ScheduleZoom((m_pBoxes[iActiveBox].iBottom - m_pBoxes[iActiveBox].iTop)/2, (m_pBoxes[iActiveBox].iBottom + m_pBoxes[iActiveBox].iTop)/2);
-      iActiveBox = 0;
+      if(iActiveBox != m_iNumBoxes-1)
+	iActiveBox = 0;
       break;
     }
   }
   else {
     if(m_iStyle == 3) {
       switch(iId) {
-      case 1:
+      case 2:
 	if(m_iLastBox == 1)
 	  pModel->ScheduleZoom((m_pBoxes[2].iBottom - m_pBoxes[2].iTop)/2, (m_pBoxes[2].iBottom + m_pBoxes[2].iTop)/2);
 	else
 	  pModel->ScheduleZoom((m_pBoxes[0].iBottom - m_pBoxes[0].iTop)/2, (m_pBoxes[0].iBottom + m_pBoxes[0].iTop)/2);
 	m_iLastBox = 1;
 	break; 
-      case 2:
+      case 3:
+      case 4:
 	if(m_iLastBox == 2)
 	  pModel->ScheduleZoom((m_pBoxes[3].iBottom - m_pBoxes[3].iTop)/2, (m_pBoxes[3].iBottom + m_pBoxes[3].iTop)/2);
 	else
 	  pModel->ScheduleZoom((m_pBoxes[1].iBottom - m_pBoxes[1].iTop)/2, (m_pBoxes[1].iBottom + m_pBoxes[1].iTop)/2);
 	m_iLastBox = 2;
 	break;
-      case 3:
+      case 1:
 	pModel->ScheduleZoom((m_pBoxes[4].iBottom - m_pBoxes[4].iTop)/2, (m_pBoxes[4].iBottom + m_pBoxes[4].iTop)/2);
 	break;
       }
     }
     else {
-      if(iId <= m_iNumBoxes) 
-	pModel->ScheduleZoom((m_pBoxes[iId-1].iBottom - m_pBoxes[iId-1].iTop)/2, (m_pBoxes[iId-1].iBottom + m_pBoxes[iId-1].iTop)/2);
+      if(iId == 100) // Ignore mouse events
+	return;
+      if(iId == 1)
+	iActiveBox = m_iNumBoxes - 1;
+      else if(iId <= m_iNumBoxes) 
+	iActiveBox = iId-2;
+      else
+	iActiveBox = m_iNumBoxes-2;
+
+      m_iLastTime = iTime;
+	
+      pModel->ScheduleZoom((m_pBoxes[iActiveBox].iBottom - m_pBoxes[iActiveBox].iTop)/2, (m_pBoxes[iActiveBox].iBottom + m_pBoxes[iActiveBox].iTop)/2);
     }
   }
 
 }
 
 void CDasherButtons::Timer(int Time, CDasherView *m_pDasherView, CDasherModel *m_pDasherModel) {
+  m_bHighlight = (Time - m_iLastTime < 200);
   m_pDasherModel->Tap_on_display(0, 0, Time, 0, 0);
 }
 
