@@ -21,14 +21,14 @@ using namespace std;
 class CDasherButtons : public CInputFilter
 {
  public:
-  CDasherButtons(Dasher::CEventHandler * pEventHandler, CSettingsStore * pSettingsStore, CDasherInterfaceBase *pInterface, int iNumBoxes, int iStyle, bool bMenu);
+  CDasherButtons(Dasher::CEventHandler * pEventHandler, CSettingsStore * pSettingsStore, CDasherInterfaceBase *pInterface, int iNumBoxes, int iStyle, bool bMenu, long long int iID, const char *szName);
 
 
   ~CDasherButtons();
 
   virtual void HandleEvent(Dasher::CEvent * pEvent);
   
-  void DecorateView(CDasherView *pView);
+  bool DecorateView(CDasherView *pView);
   
   void KeyDown(int iTime, int iId, CDasherModel *pModel);
   void Timer(int Time, CDasherView *m_pDasherView, CDasherModel *m_pDasherModel);
@@ -57,6 +57,9 @@ class CDasherButtons : public CInputFilter
 
   int iTargetWidth;
 
+  int m_iLastTime;
+  bool m_bHighlight;
+
 };
 
 #endif
