@@ -13,13 +13,13 @@
 #include "Alphabet/AlphIO.h"
 #include "CustomColours.h"
 #include "ColourIO.h"
+#include "ModuleManager.h"
 
 #include "AutoSpeedControl.h"
 
 #include "InputFilter.h"
 
 namespace Dasher {
-  class CDashEditbox;
   class CDasherScreen;
   class CDasherView;
   class CDasherInput;
@@ -28,7 +28,6 @@ namespace Dasher {
   class CEvent;
 }
 
-class Dasher::CDashEditbox;
 class Dasher::CDasherScreen;
 class Dasher::CDasherView;
 class Dasher::CDasherInput;
@@ -63,12 +62,6 @@ public:
 
   void Realize();
 
-  /// 
-  /// Create a settings store - to be implemented by the
-  /// platform-dependent derived class
-  ///
-
-  virtual CSettingsStore *CreateSettingsStore() = 0;
 
   ///
   /// Return a pointer to the current EventHandler (the one
@@ -133,7 +126,7 @@ public:
   /// \param pEvent The event to forward.
   /// \todo Should be protected.
 
-  virtual void ExternalEventHandler(Dasher::CEvent * pEvent);
+  virtual void ExternalEventHandler(Dasher::CEvent * pEvent) {};
 
   /// Interface level event handler. For example, responsible for
   /// restarting the Dasher model whenever parameter changes make it
@@ -143,16 +136,6 @@ public:
 
   void InterfaceEventHandler(Dasher::CEvent * pEvent);
 
-  /// Add an alphabet filename
-  /// \param Filename The filename to add
-
-  void AddAlphabetFilename(std::string Filename);
-
-  /// Add a colour filename
-  /// \param Filename The filename to add
-
-  void AddColourFilename(std::string Filename);
-
   // Widget Interface
   // -----------------------------------------------------
 
@@ -167,21 +150,6 @@ public:
 
   void NewFrame(unsigned long iTime);
 
-  /// Prompts Dasher to draw a new frame
-  /// \param Time The current time (in ms). Used to ensure a constant frame rate.
-  /// \todo MouseX and MouseY are currently ignored - remove from the definition.
-  /// \deprecated Use NewFrame instead.
-
-  void TapOn(int MouseX, int MouseY, unsigned long Time);       // Times in milliseconds
-
-  /// "Click mode"
-  /// \param x Mouse x-coord
-  /// \param y Mouse y-coord
-  /// \param width Width of canvas, in pixels
-  /// \param height Height of canvas, in pixels.
-  
-  void ClickTo(int x, int y, int width, int height);
-  
   /// Pause Dasher
   /// \todo Parameters are ignored (?) - remove from definition.
 
@@ -201,71 +169,7 @@ public:
   /// Linux drawing is always done to an offscreen buffer, so it's not
   /// needed during canvas exposure events.
 
-  void Redraw();                // correct speed.
-
-  /// Request a full redraw at the next timer event.
-
-  void RequestFullRedraw();
-
-  /// \todo Sort out difference between Redraw functions
-
-  void Redraw(int iMouseX, int iMouseY);
-
-  /// Draw the boxes for start on mouse position
-  /// \todo Shouldn't be called externally
-
-  void DrawMousePos(int MouseX, int MouseY, int iWhichBox);
-
-  /// \todo Document this
-
-  void GoTo(int MouseX, int MouseY);
-
-  /// \todo Document this
-
-  void DrawGoTo(int MouseX, int MouseY);
-
-  /// Force an update of the CScreen object without changing the pointer
-  /// \todo When is this needed?
-
-  void ChangeScreen();          // The widgets need to tell the engine when they have been
-
-  /// Force an update of the CEditbox object without changing the pointer
-  /// \todo When is this needed?
-
-  void ChangeEdit();            // affected by external interaction
-
-  /// Returns the number of symbols in the alphabet
-  /// \retval the number of symbols.
-
-  unsigned int GetNumberSymbols();      // These are needed so widgets know
-
-  /// Get the display string for a symbol
-  /// \param Symbol The symbol ID to look up.
-  /// \retval UTF-8 string to be displayed
-
-  const std::string & GetDisplayText(symbol Symbol);    // how to render the alphabet. All
-
-  /// Get the edit string for a symbol
-  /// \param Symbol The symbol ID to look up.
-  /// \retval UTF-8 string to be displayed
-
-  const std::string & GetEditText(symbol Symbol);       // strings are encoded in UTF-8
-
-  /// \todo Document this
-
-  int GetTextColour(symbol Symbol);     // the foreground colour of the text
-
-  /// \todo Document this
-
-  Opts::ScreenOrientations GetAlphabetOrientation();
-
-  /// \todo Document this
-
-  Opts::AlphabetTypes GetAlphabetType();
-
-  /// \todo Document this
-
-  const std::string GetTrainFile();
+  void Redraw(bool bRedrawNodes);                // correct speed.
 
   // App Interface
   // -----------------------------------------------------
@@ -280,21 +184,10 @@ public:
 
   void ChangeScreen(CDasherScreen * NewScreen); // We may change the widgets Dasher uses
 
-  /// Supply a new CDashEditbox to receive output events
-  /// \param NewEdit Pointer to the new CDashEditbox.
-
-  void ChangeEdit(CDashEditbox * NewEdit);      // at run time.
-
-  /// Train Dasher using a UTF-8 string
-  /// \param TrainString The training string.
-  /// \param IsMore Whether to keep state (affects how incomplete UTF-8 characters are handled at the end)
-
-  void Train(std::string * TrainString, bool IsMore);   // Training by string segments or file
-
   /// Train Dasher from a file
   /// \param Filename File to load.
 
-  void TrainFile(std::string Filename); // all training data must be in UTF-8.
+  int TrainFile(std::string Filename, int iTotalBytes, int iOffset); // all training data must be in UTF-8.
 
   /// \todo Document this
 
@@ -332,9 +225,7 @@ public:
 
   void GetColours(std::vector < std::string > *ColourList);
 
-  /// \todo Document this
-
-  void AddControlTree(ControlTree * controltree);
+  void GetPermittedValues(int iParameter, std::vector<std::string> &vList);
 
   /////////////////////////////////////////////////////////////////////////////
   // Settings Interface (CDasherSettingsInterface) - options saved between sessions
@@ -342,98 +233,88 @@ public:
 
   /// \deprecated Use parameter interface instead
 
-  void ChangeAlphabet(const std::string & NewAlphabetID);
+  /// \deprecated Use parameter interface instead
+
+  //  std::string GetCurrentAlphabet();
 
   /// \deprecated Use parameter interface instead
 
-  std::string GetCurrentAlphabet();
+  /// \deprecated Use parameter interface instead
+
+  //  std::string GetCurrentColours();
 
   /// \deprecated Use parameter interface instead
 
-  void ChangeColours(const std::string & NewColourID);
-
-  /// \deprecated Use parameter interface instead
-
-  std::string GetCurrentColours();
-
-  /// \deprecated Use parameter interface instead
-
-  void ChangeMaxBitRate(double NewMaxBitRate);
+  //  void ChangeMaxBitRate(double NewMaxBitRate);
 
   // DJW - nasty thing about this is - we dont necessarily want the LM to rebuild every
   // time a parameter is change - e.g. if we change 2 or 3 params in a row ???
 
   /// \deprecated Use parameter interface instead
 
-  void ChangeLanguageModel(int NewLanguageModelID);
+/*   void ChangeLanguageModel(int NewLanguageModelID); */
 
   /// \deprecated Use parameter interface instead
 
-  void ChangeView(unsigned int NewViewID);
-
   /// \deprecated Use parameter interface instead
 
-  void ChangeOrientation(Opts::ScreenOrientations Orientation);
+/*   void SetFileEncoding(Opts::FileEncodingFormats Encoding); */
 
-  /// \deprecated Use parameter interface instead
+/*   /// \deprecated Not part of Dasher control */
 
-  void SetFileEncoding(Opts::FileEncodingFormats Encoding);
+/*   void ShowToolbar(bool Value); */
 
-  /// \deprecated Not part of Dasher control
+/*   /// \deprecated Not part of Dasher control */
 
-  void ShowToolbar(bool Value);
+/*   void ShowToolbarText(bool Value); */
 
-  /// \deprecated Not part of Dasher control
+/*   /// \deprecated Not part of Dasher control */
 
-  void ShowToolbarText(bool Value);
+/*   void SetScreenSize(long Width, long Height); */
 
-  /// \deprecated Not part of Dasher control
+/*   /// \deprecated Not part of Dasher control */
 
-  void SetScreenSize(long Width, long Height);
+/*   void SetEditHeight(long Value); */
 
-  /// \deprecated Not part of Dasher control
+/*   /// \deprecated Not part of Dasher control */
 
-  void SetEditHeight(long Value);
+/*   void SetEditFont(std::string Name, long Size); */
 
-  /// \deprecated Not part of Dasher control
+/*   /// \deprecated Use parameter interface instead */
 
-  void SetEditFont(std::string Name, long Size);
+/*   void SetDasherFont(std::string Name); */
 
-  /// \deprecated Use parameter interface instead
+/*   /// \deprecated Use parameter interface instead */
 
-  void SetDasherFont(std::string Name);
+/*   void SetDasherFontSize(Dasher::Opts::FontSize fontsize); */
 
-  /// \deprecated Use parameter interface instead
+/*   /// \deprecated Use parameter interface instead */
 
-  void SetDasherFontSize(Dasher::Opts::FontSize fontsize);
+/*   void SetDasherDimensions(bool Value); */
 
-  /// \deprecated Use parameter interface instead
+/*   /// \deprecated Use parameter interface instead */
 
-  void SetDasherDimensions(bool Value);
+/*   void SetDasherEyetracker(bool Value); */
 
-  /// \deprecated Use parameter interface instead
+/*   /// \deprecated Use parameter interface instead */
 
-  void SetDasherEyetracker(bool Value);
+/*   void SetUniform(int Value); */
 
-  /// \deprecated Use parameter interface instead
+/*   /// \deprecated Use parameter interface instead */
 
-  void SetUniform(int Value);
+/*   void SetYScale(int Value); */
 
-  /// \deprecated Use parameter interface instead
+/*   /// \deprecated Use parameter interface instead */
 
-  void SetYScale(int Value);
+/*   void SetMousePosDist(int Value); */
 
-  /// \deprecated Use parameter interface instead
+/*   /// \deprecated Use parameter interface instead */
 
-  void SetMousePosDist(int Value);
+/*   void SetTruncation(int Value); */
 
-  /// \deprecated Use parameter interface instead
+/*   /// \deprecated Use parameter interface instead */
 
-  void SetTruncation(int Value);
-
-  /// \deprecated Use parameter interface instead
-
-  void SetTruncationType(int Value);
+/*   void SetTruncationType(int Value); */
 
   /// Get the current autocalibration offset
   /// \retval The offset.
@@ -442,18 +323,17 @@ public:
 
   /// \todo Document this
 
-  void Render();
+  //  void Render();
 
   /// Provide a new CDasherInput input device object.
-  /// \param _pInput Pointer to the new object
 
-  void SetInput(CDasherInput * _pInput);
+  void CreateInput();
 
   /// Set the context in which Dasher makes predictions
   /// \param strNewContext The new context (UTF-8)
 
   void SetContext(std::string strNewContext);
-  void InvalidateContext();
+  void InvalidateContext(bool bForceStart);
 
   /// Get the total number of nats (base-e bits) entered.
   /// \retval The current total
@@ -472,18 +352,11 @@ public:
     return m_Alphabet;
   }
 
-  /// Get a pointer to the CDashEditbox
-
-  CDashEditbox *GetEditbox() {
-    return m_DashEditbox;
-  }
-
-
   // Control mode stuff
   
   void RegisterNode( int iID, const std::string &strLabel, int iColour );
-  
   void ConnectNode(int iChild, int iParent, int iAfter);
+  void DisconnectNode(int iChild, int iParent);
 
   /// Gets a pointer to the object doing user logging
   CUserLog*       GetUserLogPtr();
@@ -494,43 +367,57 @@ public:
   void KeyDown(int iTime, int iId);
   void KeyUp(int iTime, int iId);
 
+  // Module management functions
+  void RegisterFactory(CModuleFactory *pFactory);
+
+  void CreateFactories();
+
+  void StartShutdown();
+
 protected:
   void WriteTrainFileFull();
   void WriteTrainFilePartial();
 
-  void CreateInputFilter();
-
+  // Various 'child' components
   CAlphabet *m_Alphabet;
   CCustomColours *m_pColours;
   CDasherModel *m_pDasherModel;
-  CDashEditbox *m_DashEditbox;
   CDasherScreen *m_DasherScreen;
   CDasherView *m_pDasherView;
-  CAutoSpeedControl *m_pAutoSpeedControl;
-
   CDasherInput *m_pInput;
-
   CAlphIO *m_AlphIO;
-  CAlphIO::AlphInfo m_AlphInfo;
   CColourIO *m_ColourIO;
-  CColourIO::ColourInfo m_ColourInfo;
-
-  std::vector < std::string > m_AlphabetFilenames;
-  std::vector < std::string > m_ColourFilenames;
 
   std::string strTrainfileBuffer;
-
-  static const std::string EmptyString;
-
-  void CreateDasherModel();
-
   std::string strCurrentContext;
 
-  CEventHandler * m_pEventHandler;
+  CEventHandler *m_pEventHandler;
   CSettingsStore *m_pSettingsStore;
-  CUserLog*       m_pUserLog;               // Pointer to the object that handles logging user activity
-  CInputFilter* m_pDasherButtons;
+  CUserLog *m_pUserLog;               // Pointer to the object that handles logging user activity
+  CInputFilter* m_pInputFilter;
+  CModuleManager m_oModuleManager;
+  
+  bool m_bGlobalLock; // The big lock
+  bool m_bShutdownLock;
+  
+  // TODO: Make private?
+  CDasherModule *GetModule(long long int iID);
+  CDasherModule *GetModuleByName(const std::string &strName);
 
+ private:
+  // To be implemented by child class
+  virtual void ScanAlphabetFiles(std::vector<std::string> &vFileList) = 0;
+  virtual void ScanColourFiles(std::vector<std::string> &vFileList) = 0;
+  virtual void SetupPaths() = 0;
+  virtual void SetupUI() = 0;
+  virtual void CreateSettingsStore() = 0;
+  virtual int GetFileSize(const std::string &strFileName) = 0;
+
+  void CreateInputFilter();
+  void CreateDasherModel();
+  void ChangeAlphabet();
+  void ChangeColours();
+  void ChangeView();
 };
 
 #endif /* #ifndef __DasherInterfaceBase_h__ */
