@@ -41,7 +41,7 @@ static char THIS_FILE[] = __FILE__;
 
 // CDasherModel
 
-CDasherModel::CDasherModel(CEventHandler *pEventHandler, CSettingsStore *pSettingsStore, CDasherInterfaceBase *pDashIface)
+CDasherModel::CDasherModel(CEventHandler *pEventHandler, CSettingsStore *pSettingsStore, CDasherInterfaceBase *pDashIface, CAlphIO *pAlphIO)
 :CDasherComponent(pEventHandler, pSettingsStore), m_pDasherInterface(pDashIface), m_Root(0), total_nats(0.0), 
 m_pLanguageModel(NULL), m_pcAlphabet(NULL), m_pGameMode(NULL), m_Rootmin(0), m_Rootmax(0), m_Rootmin_min(0),
 m_Rootmax_max(0), m_dAddProb(0.0), m_dMaxRate(0.0) {
@@ -51,7 +51,25 @@ m_Rootmax_max(0), m_dAddProb(0.0), m_dMaxRate(0.0) {
   m_fr.SetMaxBitrate(m_dMaxRate);
 
   // Convert the full alphabet to a symbolic representation for use in the language model
-  m_pcAlphabet = m_pDasherInterface->GetAlphabet();
+
+  // -- put all this in a separate method
+  // TODO: Think about having 'prefered' values here, which get
+  // retrieved by DasherInterfaceBase and used to set parameters
+
+  // TODO: We might get a different alphabet to the one we asked for -
+  // if this is the case then the parameter value should be updated,
+  // but not in such a way that it causes everything to be rebuilt.
+
+  CAlphIO::AlphInfo oAlphInfo = pAlphIO->GetInfo(GetStringParameter(SP_ALPHABET_ID));
+  m_pcAlphabet = new CAlphabet(oAlphInfo);
+
+  SetStringParameter(SP_TRAIN_FILE, m_pcAlphabet->GetTrainingFile());
+  SetStringParameter(SP_DEFAULT_COLOUR_ID, m_pcAlphabet->GetPalette());
+
+  if(GetLongParameter(LP_ORIENTATION) == Dasher::Opts::AlphabetDefault)
+    SetLongParameter(LP_REAL_ORIENTATION, m_pcAlphabet->GetOrientation());
+  // --
+
   CSymbolAlphabet alphabet(m_pcAlphabet->GetNumberTextSymbols());
   alphabet.SetSpaceSymbol(m_pcAlphabet->GetSpaceSymbol());      // FIXME - is this right, or do we have to do some kind of translation?
   alphabet.SetAlphabetPointer(m_pcAlphabet);    // Horrible hack, but ignore for now.
@@ -103,6 +121,9 @@ m_Rootmax_max(0), m_dAddProb(0.0), m_dMaxRate(0.0) {
 
   m_pAlphabetManagerFactory = new CAlphabetManagerFactory(this, m_pLanguageModel);
   m_pControlManagerFactory = new CControlManagerFactory(this, m_pLanguageModel);
+#ifdef JAPANESE
+  m_pConversionManagerFactory = new CConversionManagerFactory(this, m_pLanguageModel);
+#endif
 
   m_bContextSensitive = true;
 }
@@ -121,6 +142,10 @@ CDasherModel::~CDasherModel() {
   delete m_pAlphabetManagerFactory;
   delete m_pControlManagerFactory;
 
+#ifdef JAPANESE
+  delete m_pConversionManagerFactory;
+#endif
+
   if (m_pGameMode != NULL) {
     delete m_pGameMode;
     m_pGameMode = NULL;
@@ -156,6 +181,8 @@ void CDasherModel::HandleEvent(Dasher::CEvent *pEvent) {
 void CDasherModel::Make_root(CDasherNode *whichchild)
 // find a new root node 
 {
+
+  // TODO - support for this in alphabet manager
   symbol t = m_Root->Symbol();
   if(t < m_pDasherInterface->GetAlphabet()->GetNumberTextSymbols()) {
     // Only learn if we have adaptive behaviour enabled
@@ -528,7 +555,7 @@ void CDasherModel::Tap_on_display(myint miMousex,
 
   //  std::cout << "miMouseX: " << miMousex << " miMouseY: " << miMousey << std::endl;
 
-  if(!GetBoolParameter(BP_DASHER_PAUSED)) {
+  if(!GetBoolParameter(BP_DASHER_PAUSED) && (m_deGotoQueue.size() == 0) ) {
 
   // Clear out parameters that might get passed in to track user activity
   if (pAdded != NULL)
@@ -656,42 +683,6 @@ void CDasherModel::RecursiveOutput(CDasherNode *pNode, Dasher::VECTOR_SYMBOL_PRO
 }
 
 
-void CDasherModel::GoTo(double zoomfactor, myint miMousey)
-        // work out the next viewpoint, opens some new nodes
-{
-  // Find out the current node under the crosshair
-  CDasherNode *old_under_cross = Get_node_under_crosshair();
-
-  // works out next viewpoint
-  Get_new_goto_coords(zoomfactor, miMousey);
-
-  // push node under crosshair
-
-  CDasherNode *new_under_cross = Get_node_under_crosshair();
-
-  Push_Node(new_under_cross);
-
-  // push node under goto point
-
-  // We don't have a mousex, so "emulating" one.
-  CDasherNode *node_under_goto = Get_node_under_mouse(50, miMousey);
-
-  Push_Node(node_under_goto);
-
-//      Update(m_Root,new_under_cross,0);
-
-  if(new_under_cross != old_under_cross) {
-    DeleteCharacters(new_under_cross, old_under_cross);
-  }
-
-  if(new_under_cross->isSeen() == true)
-    return;
-
-  new_under_cross->Seen(true);
-
-  OutputCharacters(new_under_cross);
-}
-
 // This is similar to Get_new_goto_coords, but doesn't actually change Rootmax and Rootmin.
 // Instead it gives information for NewGoTo to make direct changes in the root coordinates.
 #define ZOOMDENOM (1<<10)
@@ -813,7 +804,7 @@ void CDasherModel::NewGoTo(myint n1 , myint n2 , int style) {
 }
 
 
-
+// TODO - is this used any more
 void CDasherModel::OutputCharacters(CDasherNode *node) {
   if(node->Parent() != NULL && node->Parent()->isSeen() != true) {
     node->Parent()->Seen(true);
@@ -825,13 +816,9 @@ void CDasherModel::OutputCharacters(CDasherNode *node) {
     Dasher::CEditEvent oEvent(1, GetAlphabet().GetText(t));
     InsertEvent(&oEvent);
   }
-  else if(node->ControlChild() == true) {
-
-    // FIXME - control events currently not implemented
-//        m_pEditbox->outputcontrol(node->GetControlTree()->pointer,node->GetControlTree()->data,node->GetControlTree()->type);
-  }
 }
 
+// TODO - is this used any more?
 bool CDasherModel::DeleteCharacters(CDasherNode *newnode, CDasherNode *oldnode, int* pNumDeleted) {
 
   // DJW cant see how either of these can ever be NULL
@@ -873,11 +860,7 @@ bool CDasherModel::DeleteCharacters(CDasherNode *newnode, CDasherNode *oldnode,
     while(oldnode != lastseen) {
 
       oldnode->Seen(false);
-      if(oldnode->ControlChild() == true || oldnode->Symbol() == GetControlSymbol() || oldnode->Symbol() == 0) {
-        oldnode = oldnode->Parent();
-        continue;
-      }
-
+      
       oldnode->m_pNodeManager->Undo(oldnode);
       oldnode->Parent()->m_pNodeManager->Enter(oldnode->Parent());
       if (pNumDeleted != NULL)
@@ -1058,28 +1041,28 @@ void CDasherModel::Recursive_Push_Node(CDasherNode *pNode, int iDepth) {
 
 // FIXME - annoying code duplication below
 
-void CDasherModel::RenderToView(CDasherView *pView) {
-  std::vector<CDasherNode *> vNodeList;
-  std::vector<CDasherNode *> vDeleteList;
+// void CDasherModel::RenderToView(CDasherView *pView) {
+//   std::vector<CDasherNode *> vNodeList;
+//   std::vector<CDasherNode *> vDeleteList;
 
-  pView->Render(m_Root, m_Rootmin, m_Rootmax, vNodeList, vDeleteList);
+//   pView->Render(m_Root, m_Rootmin, m_Rootmax, vNodeList, vDeleteList);
 
-  if(!GetBoolParameter(BP_OLD_STYLE_PUSH)) {
-  for(std::vector<CDasherNode *>::iterator it(vNodeList.begin()); it != vNodeList.end(); ++it)
-    Push_Node(*it);
-  }
+//   if(!GetBoolParameter(BP_OLD_STYLE_PUSH)) {
+//   for(std::vector<CDasherNode *>::iterator it(vNodeList.begin()); it != vNodeList.end(); ++it)
+//     Push_Node(*it);
+//   }
   
-  for(std::vector<CDasherNode *>::iterator it(vDeleteList.begin()); it != vDeleteList.end(); ++it)
-    (*it)->Delete_children();
-}
+//   for(std::vector<CDasherNode *>::iterator it(vDeleteList.begin()); it != vDeleteList.end(); ++it)
+//     (*it)->Delete_children();
+// }
 
-bool CDasherModel::RenderToView(CDasherView *pView, int iMouseX, int iMouseY, bool bRedrawDisplay) {
+bool CDasherModel::RenderToView(CDasherView *pView, bool bRedrawDisplay) {
   std::vector<CDasherNode *> vNodeList;
   std::vector<CDasherNode *> vDeleteList;
 
   bool bReturnValue;
 
-  bReturnValue = pView->Render(m_Root, m_Rootmin, m_Rootmax, vNodeList, vDeleteList, iMouseX, iMouseY, bRedrawDisplay);
+  bReturnValue = pView->Render(m_Root, m_Rootmin, m_Rootmax, vNodeList, vDeleteList, bRedrawDisplay);
 
   if(!GetBoolParameter(BP_OLD_STYLE_PUSH)) {
   for(std::vector<CDasherNode *>::iterator it(vNodeList.begin()); it != vNodeList.end(); ++it)
@@ -1142,16 +1125,6 @@ bool CDasherModel::CheckForNewRoot(CDasherView *pView) {
   return false;
 }
 
-void CDasherModel::ClickTo(int x, int y, int width, int height, CDasherView *pView) {
-  // FIXME - we should just schedule a path here, and tap on should be responsible for following it
-
-   myint dasherx, dashery;
-
-   pView->ClickTo(x, y, dasherx, dashery);
-
-   ScheduleZoom(dasherx,dashery);
-}
-
 void CDasherModel::ScheduleZoom(int dasherx, int dashery) {
    if (dasherx < 2) { dasherx = 100; }
    int iSteps = GetLongParameter(LP_ZOOMSTEPS); 
