@@ -54,24 +54,12 @@ public:
 
   void TapOnDisplay(screenint mousex, screenint mousey, unsigned long Time, myint &iDasherX, myint &iDasherY);
   void TapOnDisplay(screenint mousex,screenint mousey, unsigned long Time, myint &iDasherX, myint &iDasherY, VECTOR_SYMBOL_PROB* pAdded = NULL, int* pNumDeleted = NULL);
-
-  ///
-  /// \todo Document this
-  ///
-  
-  void GoTo(screenint mousex, screenint mousey);
-
-  ///
-  /// Used by click mode - coordinate system conversion only
-  ///
-
-  void ClickTo(int x, int y, myint &dasherx, myint &dashery);
   
   ///
   /// \todo Document this
   ///
 
-  void DrawGoTo(screenint mousex, screenint mousey);
+/*   void DrawGoTo(screenint mousex, screenint mousey); */
 
   void NewDrawGoTo(myint iDasherMin, myint iDasherMax, bool bActive);
 
@@ -87,24 +75,6 @@ public:
 
   void ChangeScreen(CDasherScreen * NewScreen);
 
-  /// 
-  /// Draw the mouse pointer
-  ///
-
-  void DrawMouse(screenint mousex, screenint mousey);
-
-  ///
-  /// Draw the mouse line
-  ///
-
-  void DrawMouseLine(screenint mousex, screenint mousey);
-
-  ///
-  /// \todo Document this
-  ///
-
-  void DrawKeyboard();
-
   ///
   /// Draw the game mode pointer
   ///
@@ -116,10 +86,6 @@ public:
 
   void GetScaleFactor( int eOrientation, myint *iScaleFactorX, myint *iScaleFactorY );
 
-  /// Checks for start on mouse behaviour and updates which boxes are
-  /// displayed, triggers starts etc.
-
-  virtual bool HandleStartOnMouse(int iTime);
 
   ///
   /// Event handler
@@ -127,33 +93,6 @@ public:
 
   virtual void HandleEvent(Dasher::CEvent * pEvent);
 
-  /// Render a single node
-  /// \param Character Symbol ID to be drawn
-  /// \param Color The colour to draw it
-  /// \param ColorScheme Which of the alternating colour schemes to use
-  /// \param y1 Upper extent.
-  /// \param y2 Lower extent
-  /// \param mostleft The left most position in which the text (l->r)
-  /// can be displayed in order to avoid overlap. This is updated by
-  /// the function to allow for the new text
-  /// \param displaytext Text to display.
-  /// \todo Character and displaytext are redundant. We shouldn't need
-  /// to know about alphabets here, so only use the latterr
-
-  int RenderNode(const symbol Character, const int Color, Opts::ColorSchemes ColorScheme, myint y1, myint y2, int &mostleft, const std::string & displaytext, bool bShove);
-
-  ///
-  /// Recursively render all nodes in a tree. Responsible for all the Render_node calls
-  ///
-
-  int RecursiveRender(CDasherNode * Render, myint y1, myint y2, int mostleft, std::vector<CDasherNode *> &vNodeList, std::vector<CDasherNode *> &vDeleteList);
-
-  ///
-  /// Displays some nodes inside one parent node. Used to group capital letters, accents, punctuation etc.
-  ///
-  
-  void RenderGroups(CDasherNode * Render, myint y1, myint y2, int mostleft);
-
   /// 
   /// Get the automatic calibration offset
   ///
@@ -185,16 +124,6 @@ public:
     return m_ymap.map( (myint)x );
   };
 
-private:
-
-  void RecursiveRenderGroups(SGroupInfo *pCurrentGroup, std::deque<CDasherNode*>& Children, myint y1, myint y2, int mostleft);
-
-  ///
-  /// Convert input device position to Dasher co-ordinates
-  ///
-
-  void Input2Dasher(screenint iInputX, screenint iInputY, myint & iDasherX, myint & iDasherY, int iType, int iMode);
-
   /// 
   /// Convert a screen co-ordinate to Dasher co-ordinates
   ///
@@ -208,16 +137,44 @@ private:
   void Dasher2Screen(myint iDasherX, myint iDasherY, screenint & iScreenX, screenint & iScreenY);
 
   ///
-  /// Applies the 1D mode transformation
+  /// Convert input device position to Dasher co-ordinates
   ///
 
-  void Dasher2OneD(myint & iDasherX, myint & iDasherY);
+  void Input2Dasher(screenint iInputX, screenint iInputY, myint & iDasherX, myint & iDasherY, int iType, int iMode);
+
+
+private:
+
 
   ///
-  /// Applies the eyetracker mode transformation
+  /// Recursively render all nodes in a tree. Responsible for all the Render_node calls
   ///
 
-  void Dasher2Eyetracker(myint & iDasherX, myint & iDasherY);
+  int RecursiveRender(CDasherNode * Render, myint y1, myint y2, int mostleft, std::vector<CDasherNode *> &vNodeList, std::vector<CDasherNode *> &vDeleteList);
+
+  ///
+  /// Displays some nodes inside one parent node. Used to group capital letters, accents, punctuation etc.
+  ///
+  
+  void RenderGroups(CDasherNode * Render, myint y1, myint y2, int mostleft);
+
+
+  /// Render a single node
+  /// \param Character Symbol ID to be drawn
+  /// \param Color The colour to draw it
+  /// \param ColorScheme Which of the alternating colour schemes to use
+  /// \param y1 Upper extent.
+  /// \param y2 Lower extent
+  /// \param mostleft The left most position in which the text (l->r)
+  /// can be displayed in order to avoid overlap. This is updated by
+  /// the function to allow for the new text
+  /// \param displaytext Text to display.
+  /// \todo Character and displaytext are redundant. We shouldn't need
+  /// to know about alphabets here, so only use the latterr
+
+  int RenderNode(const int Color, Opts::ColorSchemes ColorScheme, myint y1, myint y2, int &mostleft, const std::string &sDisplayText, bool bShove);
+
+  void RecursiveRenderGroups(SGroupInfo *pCurrentGroup, CDasherNode *pNode, myint y1, myint y2, int mostleft);
 
   ///
   /// Trunates co-ordinates to fit on screen
@@ -225,36 +182,6 @@ private:
 
   void TruncateToScreen(screenint & iX, screenint & iY);
 
-  ///
-  /// Draw a polyline specified in Dasher co-ordinates
-  ///
-
-  void DasherPolyline(myint * x, myint * y, int n, int iWidth, int iColour);
-
-  ///
-  /// Draw a polygon specified in Dasher co-ordinates
-  ///
-
-  void DasherPolygon(myint * x, myint * y, int n, int iColour);
-
-  ///
-  /// Draw a rectangle specified in Dasher co-ordinates
-  ///
-
-  void DasherDrawRectangle(myint iLeft, myint iTop, myint iRight, myint iBottom, const int Color, int iOutlineColour, Opts::ColorSchemes ColorScheme,bool bDrawOutline, bool bFill, int iThickness);
-
-  ///
-  /// Draw a centred rectangle specified in Dasher co-ordinates (used for mouse cursor)
-  ///
-
-  void DasherDrawCentredRectangle(myint iDasherX, myint iDasherY, screenint iSize, const int Color, Opts::ColorSchemes ColorScheme, bool bDrawOutline);
-
-  ///
-  /// Draw text specified in Dasher co-ordinates
-  ///
-
-  void DasherDrawText(myint iAnchorX1, myint iAnchorY1, myint iAnchorX2, myint iAnchorY2, const std::string & sDisplayText, int &mostleft, bool bShove);
-
   ///
   /// Get minimum visible Dasher Y co-ordinate
   /// \deprecated Use VisibleRegion.
@@ -342,11 +269,6 @@ private:
 
   // the x and y non-linearities
 
-  ///
-  /// \deprecated See Screen2Dasher
-  ///
-
-  void screen2dasher(screenint mousex, screenint mousey, myint * dasherx, myint * dashery) const;
   void AutoCalibrate(screenint * mousex, screenint * mousey);
 
   ///
@@ -381,9 +303,7 @@ private:
   bool bInBox;                  // Whether we're in the mouseposstart box
   int iBoxStart;                // Time that the current box was drawn
   int iBoxEntered;              // Time when the user enttered the current box
-
-  CDelayedDraw *m_pDelayDraw;
-
+ 
   double m_dXmpa, m_dXmpb, m_dXmpc, m_dXmpd;
   screenint CanvasX, CanvasY, CanvasBorder;
 
@@ -403,7 +323,12 @@ private:
   // The factor that scale factors are multipled by 
   myint m_iScalingFactor;
 
-
+  // Cached extents of visible region
+  bool m_bVisibleRegionValid;
+  myint m_iDasherMinX;
+  myint m_iDasherMaxX;
+  myint m_iDasherMinY;
+  myint m_iDasherMaxY;
 };
 
 #include "DasherViewSquare.inl"
