@@ -6,7 +6,7 @@
 #include "Event.h"
 
 CDynamicFilter::CDynamicFilter(Dasher::CEventHandler * pEventHandler, CSettingsStore *pSettingsStore, CDasherInterfaceBase *pInterface)
-  : CInputFilter(pEventHandler, pSettingsStore, pInterface) {
+  : CInputFilter(pEventHandler, pSettingsStore, pInterface, 6, 1, "Dynamic Mode") {
   m_iTarget = 0;
 
   m_iTargetX = new int[2];
@@ -24,7 +24,6 @@ CDynamicFilter::CDynamicFilter(Dasher::CEventHandler * pEventHandler, CSettingsS
     m_iStyle = 0;
 
   bStarted = false;
-  bBackOff = false;
 }
 
 CDynamicFilter::~CDynamicFilter() {
@@ -32,7 +31,7 @@ CDynamicFilter::~CDynamicFilter() {
   delete[] m_iTargetY;  
 }
 
-void CDynamicFilter::DecorateView(CDasherView *pView) {
+bool CDynamicFilter::DecorateView(CDasherView *pView) {
 
   CDasherScreen *pScreen(pView->Screen());
 
@@ -41,27 +40,29 @@ void CDynamicFilter::DecorateView(CDasherView *pView) {
   screenint x2;
   screenint y2;
 
-  if(m_iTarget == 0) {
-    pView->Dasher2Screen(-100, 1000, x1, y1);
+  if(m_iTarget == 1) {
+    pView->Dasher2Screen(-100, 3096, x1, y1);
     pView->Dasher2Screen(-200, 4096, x2, y2);
   }
   else {
     pView->Dasher2Screen(-100, 0, x1, y1);
-    pView->Dasher2Screen(-200, 3096, x2, y2);
+    pView->Dasher2Screen(-200, 1000, x2, y2);
   }
 
-  pScreen->DrawRectangle(x1, y1, x2, y2, 1, 1, Opts::ColorSchemes(Objects), true, false, 1);
+  pScreen->DrawRectangle(x1, y1, x2, y2, 1, 1, Opts::ColorSchemes(Objects), true, false, 2);
     
-  if(m_iTarget == 0) {
+  if(m_iTarget == 1) {
     pView->Dasher2Screen(-100, 0, x1, y1);
-    pView->Dasher2Screen(-200, 3096, x2, y2);
+    pView->Dasher2Screen(-200, 1000, x2, y2);
   }
   else {
-    pView->Dasher2Screen(-100, 1000, x1, y1);
+    pView->Dasher2Screen(-100, 3096, x1, y1);
     pView->Dasher2Screen(-200, 4096, x2, y2);
   }
 
   pScreen->DrawRectangle(x1, y1, x2, y2, 2, 2, Opts::ColorSchemes(Objects), true, false, 1);
+
+  return true;
 }
 
 void CDynamicFilter::Timer(int Time, CDasherView *m_pDasherView, CDasherModel *m_pDasherModel) {
@@ -85,17 +86,7 @@ void CDynamicFilter::Timer(int Time, CDasherView *m_pDasherView, CDasherModel *m
 }
 
 void CDynamicFilter::KeyDown(int iTime, int iId, CDasherModel *pModel) {
-  switch(iId) {
-  case 0: // Start on space
-    // FIXME - wrap this in a 'start/stop' method (and use for buttons as well as keys)
-    if(GetBoolParameter(BP_START_SPACE) && !GetBoolParameter(BP_CLICK_MODE)) {
-      if(GetBoolParameter(BP_DASHER_PAUSED))
-      	m_pInterface->Unpause(iTime);
-      else
-      	m_pInterface->PauseAt(0, 0);
-    }
-    break; 
-  case 1:
+  if((iId == 2) || (iId == 3) || (iId == 4)) {
     if(GetBoolParameter(BP_DASHER_PAUSED)) {
       m_pInterface->Unpause(iTime);
       m_iKeyTime = iTime;
@@ -105,25 +96,23 @@ void CDynamicFilter::KeyDown(int iTime, int iId, CDasherModel *pModel) {
       bStarted = true;
       m_iKeyTime = iTime;
     }
-    break;
-  case 2:
+  }
+  else if(iId == 1) {
     bBackOff = true;
-    break;
-  case 100: // Start on mouse
-    if(GetBoolParameter(BP_START_MOUSE)) {
-      if(GetBoolParameter(BP_DASHER_PAUSED))
-      	m_pInterface->Unpause(iTime);
-      else
-      	m_pInterface->PauseAt(0, 0);
+  }
+  else if(iId == 0) {
+    if(GetBoolParameter(BP_DASHER_PAUSED)) {
+      m_pInterface->Unpause(iTime);
+      m_iKeyTime = iTime;
+    }
+    else {
+      m_pInterface->PauseAt(0,0); 
     }
-    break;
-  default:
-    break;
   }
 }
 
 void CDynamicFilter::KeyUp(int iTime, int iId, CDasherModel *pModel) {
-  if(iId == 2) {
+  if(iId == 1) {
     bBackOff = false;
   }
 }
