@@ -4,21 +4,21 @@
 #include "DasherView.h"
 #include "DasherModel.h"
 
-#include "DasherComponent.h"
+#include "DasherModule.h"
 
 namespace Dasher {
   class CDasherInterfaceBase;
 }
 
-class CInputFilter : public CDasherComponent {
+class CInputFilter : public CDasherModule {
  public:
-  CInputFilter(Dasher::CEventHandler * pEventHandler, CSettingsStore * pSettingsStore, CDasherInterfaceBase *pInterface)
-    : CDasherComponent(pEventHandler, pSettingsStore) {
+  CInputFilter(Dasher::CEventHandler * pEventHandler, CSettingsStore * pSettingsStore, CDasherInterfaceBase *pInterface, long long int iID, int iType, const char *szName)
+    : CDasherModule(pEventHandler, pSettingsStore, iID, iType, szName) {
     m_pInterface = pInterface;
   };
 
   virtual void HandleEvent(Dasher::CEvent * pEvent) {};
-  virtual void DecorateView(CDasherView *pView) {};
+  virtual bool DecorateView(CDasherView *pView) { return false; };
   virtual void KeyDown(int Time, int iId, CDasherModel *pModel) {};
   virtual void KeyUp(int Time, int iId, CDasherModel *pModel) {};
   virtual void Timer(int Time, CDasherView *m_pDasherView, CDasherModel *m_pDasherModel) {};
