@@ -5,7 +5,7 @@
 #include "Event.h"
 
 COneButtonFilter::COneButtonFilter(Dasher::CEventHandler * pEventHandler, CSettingsStore *pSettingsStore, CDasherInterfaceBase *pInterface)
-  : CInputFilter(pEventHandler, pSettingsStore, pInterface) {
+  : CInputFilter(pEventHandler, pSettingsStore, pInterface, 9, 1, "One Button Mode") {
 
   bStarted = 0;
   iLocation = 0;
@@ -15,7 +15,7 @@ COneButtonFilter::COneButtonFilter(Dasher::CEventHandler * pEventHandler, CSetti
 COneButtonFilter::~COneButtonFilter() {
 }
 
-void COneButtonFilter::DecorateView(CDasherView *pView) {
+bool COneButtonFilter::DecorateView(CDasherView *pView) {
   CDasherScreen *pScreen(pView->Screen());
   CDasherScreen::point p[2];
  
@@ -33,6 +33,8 @@ void COneButtonFilter::DecorateView(CDasherView *pView) {
   pView->Dasher2Screen(iDasherX, iDasherY, p[1].x, p[1].y);
   
   pScreen->Polyline(p, 2, 1, 1);
+
+  return true;
 }
 
 void COneButtonFilter::Timer(int Time, CDasherView *m_pDasherView, CDasherModel *m_pDasherModel) {
