@@ -125,9 +125,15 @@ HWND CDasherWindow::Create()
 
   // Create the Main window
   //Tstring WndClassName = CreateMyClass();
+// Create a CAppSettings
+  m_pAppSettings = new CAppSettings(0, 0);
+  int iStyle(m_pAppSettings->GetLongParameter(APP_LP_STYLE));
 
-
-  HWND hWnd = CWindowImpl<CDasherWindow>::Create(NULL, NULL, WindowTitle.c_str(), WS_OVERLAPPEDWINDOW | WS_CLIPCHILDREN);
+  HWND hWnd;
+  if((iStyle == 1) || (iStyle == 2))
+    hWnd = CWindowImpl<CDasherWindow >::Create(NULL, NULL, WindowTitle.c_str(), WS_OVERLAPPEDWINDOW | WS_CLIPCHILDREN,  WS_EX_NOACTIVATE | WS_EX_APPWINDOW | WS_EX_TOPMOST);
+  else
+    hWnd = CWindowImpl<CDasherWindow >::Create(NULL, NULL, WindowTitle.c_str(), WS_OVERLAPPEDWINDOW | WS_CLIPCHILDREN);
 
   // Splash screen (turned off for debugging when it gets in the way)
   // It is deleted when Show() is called.
@@ -143,9 +149,10 @@ HWND CDasherWindow::Create()
   m_pDasher = new CDasher(hWnd);
 
   // Create a CAppSettings
-  m_pAppSettings = new CAppSettings(m_pDasher, hWnd);
+  m_pAppSettings->SetHwnd(hWnd);
+  m_pAppSettings->SetDasher(m_pDasher);
 
-  m_pEdit = new CEdit();
+  m_pEdit = new CEdit(m_pAppSettings);
   m_pEdit->Create(hWnd, m_pAppSettings->GetBoolParameter(APP_BP_TIME_STAMP));
   m_pEdit->SetFont(m_pAppSettings->GetStringParameter(APP_SP_EDIT_FONT), m_pAppSettings->GetLongParameter(APP_LP_EDIT_FONT_SIZE));
 
@@ -305,6 +312,9 @@ void CDasherWindow::HandleParameterChange(int iParameter) {
    case APP_BP_SHOW_TOOLBAR:
     m_pToolbar->ShowToolbar(m_pAppSettings->GetBoolParameter(APP_BP_SHOW_TOOLBAR));
     break;
+   case APP_LP_STYLE:
+     Layout();
+     break;
    case APP_BP_TIME_STAMP:
     m_pEdit->TimeStampNewFiles(m_pAppSettings->GetBoolParameter(APP_BP_TIME_STAMP));
     break;
@@ -312,6 +322,7 @@ void CDasherWindow::HandleParameterChange(int iParameter) {
 	  m_pSlidebar->SetValue(m_pAppSettings->GetLongParameter(LP_MAX_BITRATE) / 100.0);
 	  break;
    case BP_DASHER_PAUSED:
+     // TODO: This should be triggered on start/stop event, not here
     if(m_pAppSettings && m_pDasher && 
        m_pAppSettings->GetBoolParameter(BP_DASHER_PAUSED) && 
        m_pAppSettings->GetBoolParameter(APP_BP_COPY_ALL_ON_STOP))
@@ -320,7 +331,7 @@ void CDasherWindow::HandleParameterChange(int iParameter) {
     break;
    case APP_SP_EDIT_FONT:
    case APP_LP_EDIT_FONT_SIZE:
-     m_pEdit->SetFont(m_pAppSettings->GetStringParameter(APP_SP_EDIT_FONT),m_pAppSettings->GetLongParameter(APP_LP_EDIT_FONT_SIZE));
+     m_pEdit->SetFont(m_pAppSettings->GetStringParameter(APP_SP_EDIT_FONT), m_pAppSettings->GetLongParameter(APP_LP_EDIT_FONT_SIZE));
      break;
   }
 }
@@ -438,50 +449,59 @@ LRESULT CDasherWindow::OnCommand(UINT message, WPARAM wParam, LPARAM lParam, BOO
 		  return 0;
 	  case ID_OPTIONS_CONTROLMODE:
 		  m_pDasher->SetBoolParameter(BP_CONTROL_MODE, !WinMenu.GetCheck(ID_OPTIONS_CONTROLMODE));
-		  m_pDasher->RequestFullRedraw();
+//		  m_pDasher->RequestFullRedraw();
 		  return 0;
 	  case ID_OPTIONS_FONTSIZE_NORMAL:
 		  m_pDasher->SetLongParameter(LP_DASHER_FONTSIZE, Dasher::Opts::FontSize(1));
-		  m_pDasher->RequestFullRedraw();
+//		  m_pDasher->RequestFullRedraw();
 		  break;
 	  case ID_OPTIONS_FONTSIZE_LARGE:
 		  m_pDasher->SetLongParameter(LP_DASHER_FONTSIZE, Dasher::Opts::FontSize(2));
-		  m_pDasher->RequestFullRedraw();
+//		  m_pDasher->RequestFullRedraw();
 		  break;
 	  case ID_OPTIONS_FONTSIZE_VERYLARGE:
 		  m_pDasher->SetLongParameter(LP_DASHER_FONTSIZE, Dasher::Opts::FontSize(4));
-		  m_pDasher->RequestFullRedraw();
+//		  m_pDasher->RequestFullRedraw();
 		  break;
 	  case ID_OPTIONS_EDITFONT:{
 		  CHOOSEFONT Data;
 		  LOGFONT lf;
-		  HFONT Font = (HFONT) GetStockObject(DEFAULT_GUI_FONT);
-		  GetObject(Font, sizeof(LOGFONT), &lf);
+      HFONT Font = (HFONT) GetStockObject(DEFAULT_GUI_FONT);
+      GetObject(Font, sizeof(LOGFONT), &lf);
+      Tstring tstrFaceName;
+      WinUTF8::UTF8string_to_wstring(m_pAppSettings->GetStringParameter(APP_SP_EDIT_FONT), tstrFaceName);
+      _tcscpy(lf.lfFaceName, tstrFaceName.c_str());
+      lf.lfHeight = m_pAppSettings->GetLongParameter(APP_LP_EDIT_FONT_SIZE);
 		  Data.Flags = CF_INITTOLOGFONTSTRUCT | CF_SCREENFONTS;
 		  Data.lStructSize = sizeof(CHOOSEFONT);
 		  Data.hwndOwner = m_hWnd;
 		  Data.lpLogFont = &lf;
-		  ChooseFont(&Data);
-		  string FontName;
-		  WinUTF8::wstring_to_UTF8string(lf.lfFaceName, FontName);
-		  m_pAppSettings->SetStringParameter(APP_SP_EDIT_FONT, FontName);
-      m_pAppSettings->SetLongParameter(APP_LP_EDIT_FONT_SIZE, lf.lfHeight);
-							   }
-							   break;
+      if(ChooseFont(&Data)) {
+		    string FontName;
+		    WinUTF8::wstring_to_UTF8string(lf.lfFaceName, FontName);
+		    m_pAppSettings->SetStringParameter(APP_SP_EDIT_FONT, FontName);
+        m_pAppSettings->SetLongParameter(APP_LP_EDIT_FONT_SIZE, lf.lfHeight);
+      }
+	    }
+			break;
 	  case ID_OPTIONS_DASHERFONT:
 		  {
 		  CHOOSEFONT Data;
 		  LOGFONT lf;
 		  HFONT Font = (HFONT) GetStockObject(DEFAULT_GUI_FONT);
 		  GetObject(Font, sizeof(LOGFONT), &lf);
+      Tstring tstrFaceName;
+      WinUTF8::UTF8string_to_wstring(m_pAppSettings->GetStringParameter(SP_DASHER_FONT), tstrFaceName);
+      _tcscpy(lf.lfFaceName, tstrFaceName.c_str());
 		  Data.Flags = CF_INITTOLOGFONTSTRUCT | CF_SCREENFONTS;
 		  Data.lStructSize = sizeof(CHOOSEFONT);
 		  Data.hwndOwner = m_hWnd;
 		  Data.lpLogFont = &lf;
-		  ChooseFont(&Data);
-		  string FontName;
-		  WinUTF8::wstring_to_UTF8string(lf.lfFaceName, FontName);
-		  m_pAppSettings->SetStringParameter(SP_DASHER_FONT, FontName);
+      if(ChooseFont(&Data)) {
+		    string FontName;
+ 		    WinUTF8::wstring_to_UTF8string(lf.lfFaceName, FontName);
+  		  m_pAppSettings->SetStringParameter(SP_DASHER_FONT, FontName);
+      }
 		 }
 		 return 0;
 	  case ID_OPTIONS_RESETFONT:
@@ -519,8 +539,7 @@ LRESULT CDasherWindow::OnCommand(UINT message, WPARAM wParam, LPARAM lParam, BOO
 		  return 0;
 	  case IDM_EXIT:
 		  //SendMessage(m_hWnd, WM_CLOSE, 0, 0);
-		  if(m_pEdit->QueryClose())
-        DestroyWindow();
+		  DestroyWindow();
 		  return 0;
 	
 		  // FIXME - These options shouldn't pass through the interface
@@ -580,7 +599,8 @@ LRESULT CDasherWindow::OnCommand(UINT message, WPARAM wParam, LPARAM lParam, BOO
 			  m_pEdit->SaveAs();
 		  return 0;
 	  case ID_IMPORT_TRAINFILE:
-		  m_pDasher->TrainFile(m_pEdit->Import());
+      // TODO: Fix dummy arguments
+		  m_pDasher->TrainFile(m_pEdit->Import(),0,0);
 		  return 0;
 	
 		  // FIXME - This options shouldn't passs through the interface
@@ -666,14 +686,12 @@ LRESULT CDasherWindow::OnDasherEvent(UINT message, WPARAM wParam, LPARAM lParam,
           m_pEdit->HandleEvent(pEvent);
         break;
       case EV_EDIT_CONTEXT:
-        if(m_pEdit && m_pDasher)
-          m_pDasher->SetContext(m_pEdit->GetContext(((CEditContextEvent*)pEvent)->m_iMaxLength));
         break;
       case EV_START:
         break;
       case EV_STOP:
-        //if(m_pEdit)
-          //m_pEdit->speak(2);
+        if(m_pEdit)
+          m_pEdit->speak(2);
         break;
       case EV_CONTROL:
         HandleControlEvent(((CControlEvent *)pEvent)->m_iID);
@@ -699,8 +717,7 @@ LRESULT CDasherWindow::OnDestroy(UINT message, WPARAM wParam, LPARAM lParam, BOO
 {
 	bHandled = TRUE;
 	OutputDebugString(TEXT("DasherWindow WM_DESTROY\n"));
-  //if(m_pEdit)
-	 // m_pEdit->New();
+
 	if(m_pEdit != 0) {
 		m_pEdit->write_to_file();
 	}
@@ -735,12 +752,9 @@ LRESULT CDasherWindow::OnInitMenuPopup(UINT message, WPARAM wParam, LPARAM lPara
 
 LRESULT CDasherWindow::OnClose(UINT message, WPARAM wParam, LPARAM lParam, BOOL& bHandled)
 {
-	bHandled = TRUE;
-  if(m_pEdit->QueryClose()) {
-	  SaveWindowState();
-    DestroyWindow();
-  }
-  return 0;
+	bHandled = FALSE;
+	SaveWindowState();
+	return 0;
 }
 
 LRESULT CDasherWindow::OnSize(UINT message, WPARAM wParam, LPARAM lParam, BOOL& bHandled)
@@ -795,8 +809,25 @@ LRESULT CDasherWindow::OnOther(UINT message, WPARAM wParam, LPARAM lParam, BOOL&
  //   break;
 
 
-void CDasherWindow::Layout() 
-{
+void CDasherWindow::Layout() {
+  int iStyle(m_pAppSettings->GetLongParameter(APP_LP_STYLE));
+  
+  // Set up the window properties
+
+  if((iStyle == 1) || (iStyle == 2)) {
+    SetWindowLong(GWL_EXSTYLE, GetWindowLong(GWL_EXSTYLE) | WS_EX_NOACTIVATE | WS_EX_APPWINDOW);
+    SetWindowPos(HWND_TOPMOST, 0, 0, 0, 0, SWP_NOMOVE | SWP_NOSIZE);
+  }
+  else {
+    SetWindowLong(GWL_EXSTYLE, GetWindowLong(GWL_EXSTYLE) & !WS_EX_NOACTIVATE);
+    SetWindowPos(HWND_NOTOPMOST, 0, 0, 0, 0, SWP_NOMOVE | SWP_NOSIZE);
+  }
+
+  // Now do the actual layout
+
+  bool bHorizontal(iStyle == 1); 
+  bool bShowEdit(iStyle != 2);
+
   RECT ClientRect;
   GetClientRect( &ClientRect);
   const int Width = ClientRect.right;
@@ -823,14 +854,33 @@ void CDasherWindow::Layout()
     SplitterPos = min(SplitterPos, MaxCanvas - 3 * SplitterHeight);
     m_pSplitter->Move(SplitterPos, Width);
 
-    if(m_pEdit)
-      m_pEdit->Move(0, CurY, Width, SplitterPos - CurY);
+    if(bHorizontal) {
+      if(m_pCanvas)
+        m_pCanvas->Move(0, CurY, Width / 2, MaxCanvas - CurY);
 
-    CurY = SplitterPos + SplitterHeight;
-    int CanvasHeight = Height - CurY - SlidebarHeight - GetSystemMetrics(SM_CYEDGE);
+      if(m_pEdit)
+        m_pEdit->Move(Width / 2, CurY, Width / 2, MaxCanvas - CurY);
+    }
+    else {
+      if(bShowEdit) {
+        m_pEdit->ShowWindow(SW_SHOW);
+        m_pSplitter->ShowWindow(SW_SHOW);
+
+        if(m_pEdit)
+          m_pEdit->Move(0, CurY, Width, SplitterPos - CurY);
+
+        CurY = SplitterPos + SplitterHeight;
+      }
+      else {
+        m_pEdit->ShowWindow(SW_HIDE);
+        m_pSplitter->ShowWindow(SW_HIDE);
+      }
+
+      int CanvasHeight = Height - CurY - SlidebarHeight - GetSystemMetrics(SM_CYEDGE);
  
-    if(m_pCanvas)
-      m_pCanvas->Move(0, CurY, Width, CanvasHeight);
+      if(m_pCanvas)
+        m_pCanvas->Move(0, CurY, Width, CanvasHeight);
+     }
   }
 }
 
