@@ -11,7 +11,7 @@
 	TODO YUCK. Sorry I do appreciate that this is a *total* mess.
 */
 
-#include "WinCommon.h"
+#include "..\Common\WinCommon.h"
 
 #include "Slidebar.h"
 #include "../resource.h"
